California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 25 - 2000 ELECTION CAMPAIGNS. CONTRIBUTION AND SPENDING LIMITS. PUBLIC FINANCING. DISCLOSURES. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990416 | VOTERS RIGHTS 2000 - YES ON 25 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991931 | TAXPAYERS FOR FAIR ELECTIONS/NO ON PROP. 25, A COALITION OF TAXPAYERS, SENIORS, TEACHERS, BUSINESS, LABOR AND CAMPAIGN FINANCE REFORM EXPERTS | OPPOSE